<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<!-- ======================================================== -->
<!-- ===   Mill XSL Simple Tool List File                 === -->
<!-- ======================================================== -->
<!-- === Creation Date: 9/2013                            === -->
<!-- === Developed by BobCAD-CAM                          === -->
<!-- === Software Version: V26                            === -->
<!-- ======================================================== -->
<!-- === Revision Log:                                    === -->
<!-- === 9/17/2013 - ACC - Orig Creation                  === -->
<!-- ===                                                  === -->
<!-- ===                                                  === -->
<!-- ===                                                  === -->
<!-- ===                                                  === -->
<!-- ======================================================== -->
<!-- === This document is the code file used              === -->
<!-- === to format the XML file generated by              === -->
<!-- === the BobCAD-CAM software.  This XSL               === -->
<!-- === works together with the CSS file to              === -->
<!-- === control the format and display of                === -->
<!-- === the Tool List File.                              === -->
<!-- ======================================================== -->

<xsl:template match="/">
		<html>
		<!-- ================================================ -->
		<!-- === Page Title (displayed on tabs in browser === -->
		<title>BobCAD-CAM Setup Sheet</title>

	<head>
		<!-- ========================================================================= -->
		<!-- === Link to CSS file used with this template                          === -->
		<link rel="stylesheet" type="text/css" href="./stylesheets/bcss_style.css"></link>


		<!-- ######################################################################### -->
		<!-- === Document Header Section - This area is used to format the image and   -->
		<!-- ===  title text displayed at the very top of the setup sheet document     -->
		<table style="padding-bottom: 0px;" id="doc-header" summary="Header of the document">
			<tr>
				<!-- ================================================================= -->
				<!-- === Header Text and Link to File Name (Generates in Header)   === -->
				<td class="c1">Setup Sheet for <xsl:value-of select="setup_sheet/header_data/file_name"/></td>
			</tr>
		</table>
	</head>
	
	<body>
		<!-- ######################################################################### -->
		<!-- === General Program Data Section - This section contains the code         -->
		<!-- ===  that is outputting the Job Information Table in the setup            -->
		<!-- ===  sheet.  Any changes you wish to make to the table items will         -->
		<!-- ===  be found in this section                                             -->
    <table>
      <tr>
        <td style="border: solid 1px; vertical-align: top">
      		<table id="prog-data" summary="General Program Data">
      			<tbody>
      				<!-- ================================================================= -->
      				<!-- === Enter any header column names in this section.            === -->
      				<!-- ===  This table is formatted with 2 columns.  The 1st column  === -->
      				<!-- ===  is much narrower than the 2nd column.                    === -->
      				<tr>
      				    <!-- ============================================================= -->
      				    <!-- === Column 1 Header Text                                  === -->
      					<td class="colh1" scope="col" colspan="2">Job Information</td>
      					<!-- ============================================================= -->
      					<!-- === Column 2 Header Text                                  === -->
      					<!-- None because the 1st column is spanning 2 columns -->
      				</tr>
              <tr>
                <td colspan="2"><div style="border-bottom: dashed 1px;"></div></td>
              </tr>
      				<!-- ================================================================= -->
      				<!-- === Table data section - This section contains the data that  === -->
      				<!-- ===   gets populated into the Genaral Program Data Table      === -->
      				<tr>
      					<!-- ============================================================= -->
      					<!-- === Row 1 Column 1 Text - Program Number                  === -->
      					<td class="col1" scope="col">Program Number:</td>
      					<!-- === Row 1 Column 2 Data - Program Number                  === -->					
      					<td class="col2" scope="col"><xsl:value-of select="setup_sheet/header_data/prog_num"/></td>
      				</tr>
      				<tr>
      					<!-- ============================================================= -->
      					<!-- === Row 2 Column 1 Text - File Name                       === -->
      					<td class="col1" scope="col">File Name:</td>
      					<!-- === Row 2 Column 2 Text - File Name                       === -->
      					<td class="col2" scope="col"><xsl:value-of select="setup_sheet/header_data/file_name"/></td>
      				</tr>	
      				<tr>
      					<!-- ============================================================= -->
      					<!-- === Row 3 Column 1 Text - NC File Name                    === -->
      					<td class="col1" scope="col">NC File Name:</td>
      					<!-- === Row 3 Column 2 Text - NC File Name                    === -->
      					<td class="col2" scope="col"><xsl:value-of select="setup_sheet/header_data/nc_filename"/></td>
      				</tr>
      				<tr>
      					<!-- ============================================================= -->
      					<!-- === Row 4 Column 1 Text - Machine Name                    === -->
      					<td class="col1" scope="col">Machine Name:</td>
      					<!-- === Row 4 Column 2 Text - Machine Name                    === -->
      					<td class="col2" scope="col"><xsl:value-of select="setup_sheet/header_data/machine_name"/></td>
      				</tr>				
      				<tr>
      					<!-- ============================================================= -->
      					<!-- === Row 5 Column 1 Text - Post Processor Name             === -->
      					<td class="col1" scope="col">Post Processor Name:</td>
      					<!-- === Row 5 Column 2 Text - Post Processor Name             === -->
      					<td class="col2" scope="col"><xsl:value-of select="setup_sheet/header_data/post_name"/></td>
      				</tr>
      				<tr>
      					<!-- ============================================================= -->
      					<!-- === Row 6 Column 1 Text - Date                            === -->
      					<td class="col1" scope="col">Date:</td>
      					<!-- === Row 6 Column 2 Text - Date                            === -->
      					<td class="col2" scope="col"><xsl:value-of select="setup_sheet/header_data/date"/></td>
      				</tr>
      			</tbody>
      		</table>
        </td>
      
        <td style="border: solid 1px; vertical-align: top">
      		<!-- ######################################################################### -->
      		<!-- === User Comment Output Section - This section contains the code          -->
      		<!-- ===  that is outputting any user comments that have been entered into     -->
      		<!-- ===  the system for this job.                                             -->
      		<table id="comments" summary="User Comment Section">
      			<tbody>
      			<!-- ================================================================= -->
      			<!-- === Enter any header column names in this section.            === -->
      
      				<!-- ============================================================= -->
      				<!-- === Row 1 Header Text                                     === -->
      				<tr>
                <td class="comh1">User Comments</td>
              </tr>
              
              <tr>
                <td colspan="2"><div style="border-bottom: dashed 1px;"></div></td>
              </tr>
              
      				<!-- ============================================================= -->
      				<!-- === The following code tests to see if comments have been === -->
      				<!-- ===  entered into any of the 15 user comment fields in    === -->
      				<!-- ===  the system.                                          === -->
      				<xsl:for-each select="setup_sheet/comments/user_comment">
      					<tr>
      						<td class="com1"><xsl:value-of select="current()"/></td>
      					</tr>
                      </xsl:for-each>
      				<xsl:if test="count(//user_comment) = 0">
      					<tr>
      						<td class="com1" height="25"></td>
      					</tr>
      					<tr>
      						<td class="com1" height="25"></td>
      					</tr>
      					<tr>
      						<td class="com1" height="25"></td>
      					</tr>
      					<tr>
      						<td class="com1" height="25"></td>
      					</tr>
      				</xsl:if>
      				<!-- ============================================================= -->
      				<!-- End of User Comment Section                               === -->
      				<!-- ============================================================= -->
      			</tbody>
      		</table>
        </td>
      </tr>
    </table>
    
		<!-- ######################################################################### -->
		<!-- === Tool List Table Output Section - This section contains the code       -->
		<!-- ===  that outputs the Tool List table.  Any output changes will be made   -->
		<!-- ===  in this section.                                                     -->
		<table id="tool-data" summary="Tool Information Table">
			<tbody>
				<tr>
					<!-- ============================================================= -->
					<!-- === Tool List Table Header Text                           === -->
					<td class="hh1" colspan="11">Tool List</td>
				</tr>
        <tr>
          <td class="hbig">T Nr.</td>
          <td class="hbig">Type:</td>
          <td class="hbig">Name:</td>
          <td class="hbig">Diameter</td>
          <td class="hbig">Num Flutes</td>
          <td class="hbig">Flute Len</td>
          <td class="hbig">Corner Rad</td>
          <td class="hbig">Protrusion Len</td>
          <td class="hbig">Tip Angle</td>
          <td class="hbig">Material</td>
          <td class="hbig">Holder</td>
        </tr>

				<!-- ================================================================= -->
				<!-- === This section begins the looping process where each tool   === -->
				<!-- ===  in the program will be checked for what type it is and   === -->
				<!-- ===  then output into the table with an image.                === -->
				<!-- === Look below if you wish to modify the tool images          === -->
				<xsl:for-each select="setup_sheet/tool_list/tool">						
					<tr>
						<!-- ========================================================= -->
						<td class="dbigR"><xsl:value-of select="tool_num"/></td>
						<td class="dbigL"><xsl:value-of select="type"/></td>
						<td class="dbigL"><xsl:value-of select="tool_label"/></td>
						<td class="dbigR"><xsl:value-of select="diameter"/></td>
            <td class="dbigR"><xsl:value-of select="num_flutes"/></td>
						<td class="dbigR"><xsl:value-of select="flute_length"/></td>
            <td class="dbigR"><xsl:value-of select="corner_rad"/></td>
            <td class="dbigR"><xsl:value-of select="protrusion_length"/></td>
            <td class="dbigR"><xsl:value-of select="tip_angle"/></td>
            <td class="dbigL"><xsl:value-of select="tool_material"/></td>
            <td class="dbigL"><xsl:value-of select="holder_label"/></td>
            
						<!-- ============================================================= -->
						<!-- This is a seperator output section for in the table       === -->
					</tr>
				</xsl:for-each>
			</tbody>
		</table>
		<!-- ========================================================================= -->
		<!-- === End of Tool List Table Section                                    === -->
		<!-- ========================================================================= -->
	</body>
	</html>
</xsl:template>
</xsl:stylesheet>